@@ -350,7 +350,7 @@
     <message>
         <location filename="../../LoginDialog.cpp" line="221"/>
         <source>&lt;qt&gt;&lt;br&gt;&lt;br&gt;&lt;p&gt;&lt;i&gt;&lt;b&gt;qtWallet&lt;/b&gt;&lt;/i&gt;, v.1.0&lt;/p&gt;&lt;p&gt;Developed by &lt;b&gt;nowheremanmail@gmail.com&lt;/b&gt;&lt;/p&gt;&lt;p&gt;Icons by http://pixelmixer.ru/&lt;/p&gt;&lt;p&gt;if you think that qtWallet is useful for you, please&lt;/p&gt;&lt;a href=&quot;https://www.paypal.com/cgi-bin/webscr?cmd=_donations&amp;business=nowheremanmail@gmail.com&amp;lc=US&amp;item_name=qtWallet&amp;currency_code=EUR&amp;bn=PP%2dDonationsBF%3abtn_donate_SM%2egif%3aNonHosted&quot;&gt;DONATE&lt;/a&gt;&lt;/qt&gt;</source>
-        <translation type="unfinished"></translation>
+        <translation>&lt;qt&gt;&lt;br&gt;&lt;br&gt;&lt;p&gt;&lt;i&gt;&lt;b&gt;Wallet&lt;/b&gt;&lt;/i&gt;, v.%1&lt;/p&gt;&lt;p&gt;Desarrollado por &lt;b&gt;nowheremanmail@gmail.com&lt;/b&gt;&lt;/p&gt;&lt;p&gt;Iconos por http://pixelmixer.ru/&lt;/p&gt;&lt;p&gt;Si piensas que Wallet es util para ti, puedes &lt;/p&gt;&lt;a href=&quot;https://www.paypal.com/cgi-bin/webscr?cmd=_donations&amp;business=nowheremanmail@gmail.com&amp;lc=US&amp;item_name=qtWallet&amp;currency_code=EUR&amp;bn=PP%2dDonationsBF%3abtn_donate_SM%2egif%3aNonHosted&quot;&gt;DONAR&lt;/a&gt;&lt;/qt&gt;</translation>
     </message>
     <message>
         <location filename="../../LoginDialog.cpp" line="243"/>
@@ -371,12 +371,12 @@
 <context>
     <name>RenameGroupDialog</name>
     <message>
-        <location filename="../../eWallet.cpp" line="49"/>
+        <location filename="../../eWallet.cpp" line="51"/>
         <source>Save &amp;&amp; Close</source>
         <translation>Enregistrer &amp;&amp; Fermer</translation>
     </message>
     <message>
-        <location filename="../../eWallet.cpp" line="62"/>
+        <location filename="../../eWallet.cpp" line="64"/>
         <source>Name</source>
         <translation>Nom</translation>
     </message>
@@ -384,491 +384,491 @@
 <context>
     <name>eWallet</name>
     <message>
-        <location filename="../../eWallet.cpp" line="366"/>
-        <location filename="../../eWallet.cpp" line="818"/>
+        <location filename="../../eWallet.cpp" line="368"/>
+        <location filename="../../eWallet.cpp" line="820"/>
         <source>&lt;All&gt;</source>
         <translation>&lt;Tout&gt;</translation>
     </message>
     <message>
-        <location filename="../../eWallet.cpp" line="385"/>
-        <location filename="../../eWallet.cpp" line="827"/>
+        <location filename="../../eWallet.cpp" line="387"/>
+        <location filename="../../eWallet.cpp" line="829"/>
         <source>&lt;No Group&gt;</source>
         <translation>&lt;Pas de groupe&gt;</translation>
     </message>
     <message>
-        <location filename="../../eWallet.cpp" line="444"/>
+        <location filename="../../eWallet.cpp" line="446"/>
         <source>Are you sure you want to remove all your data? You will lost all your data</source>
         <translation>Etes-vous sûr de vouloir supprimer toutes vos données ? Vous perdrez toutes vos données</translation>
     </message>
     <message>
-        <location filename="../../eWallet.cpp" line="469"/>
+        <location filename="../../eWallet.cpp" line="471"/>
         <source>Wrong password</source>
         <translation>Mot de passe erroné</translation>
     </message>
     <message>
-        <location filename="../../eWallet.cpp" line="529"/>
+        <location filename="../../eWallet.cpp" line="531"/>
         <source>Organization</source>
         <translation>Organisation</translation>
     </message>
     <message>
-        <location filename="../../eWallet.cpp" line="530"/>
-        <location filename="../../eWallet.cpp" line="551"/>
-        <location filename="../../eWallet.cpp" line="601"/>
+        <location filename="../../eWallet.cpp" line="532"/>
+        <location filename="../../eWallet.cpp" line="553"/>
+        <location filename="../../eWallet.cpp" line="603"/>
         <source>Phone Number</source>
         <translation>Téléphone</translation>
     </message>
     <message>
-        <location filename="../../eWallet.cpp" line="531"/>
-        <location filename="../../eWallet.cpp" line="565"/>
+        <location filename="../../eWallet.cpp" line="533"/>
+        <location filename="../../eWallet.cpp" line="567"/>
         <source>Other Information</source>
         <translation>Autre information</translation>
     </message>
     <message>
-        <location filename="../../eWallet.cpp" line="532"/>
-        <location filename="../../eWallet.cpp" line="541"/>
-        <location filename="../../eWallet.cpp" line="643"/>
+        <location filename="../../eWallet.cpp" line="534"/>
+        <location filename="../../eWallet.cpp" line="543"/>
+        <location filename="../../eWallet.cpp" line="645"/>
         <source>User Name</source>
         <translation>Nom utilisateur</translation>
     </message>
     <message>
-        <location filename="../../eWallet.cpp" line="533"/>
-        <location filename="../../eWallet.cpp" line="542"/>
-        <location filename="../../eWallet.cpp" line="569"/>
-        <location filename="../../eWallet.cpp" line="600"/>
-        <location filename="../../eWallet.cpp" line="629"/>
-        <location filename="../../eWallet.cpp" line="640"/>
-        <location filename="../../eWallet.cpp" line="644"/>
-        <location filename="../../eWallet.cpp" line="653"/>
+        <location filename="../../eWallet.cpp" line="535"/>
+        <location filename="../../eWallet.cpp" line="544"/>
+        <location filename="../../eWallet.cpp" line="571"/>
+        <location filename="../../eWallet.cpp" line="602"/>
+        <location filename="../../eWallet.cpp" line="631"/>
+        <location filename="../../eWallet.cpp" line="642"/>
+        <location filename="../../eWallet.cpp" line="646"/>
+        <location filename="../../eWallet.cpp" line="655"/>
         <source>Password</source>
         <translation>Mot de passe</translation>
     </message>
     <message>
-        <location filename="../../eWallet.cpp" line="534"/>
+        <location filename="../../eWallet.cpp" line="536"/>
         <source>Organization club</source>
         <translation>Club</translation>
     </message>
     <message>
-        <location filename="../../eWallet.cpp" line="535"/>
-        <location filename="../../eWallet.cpp" line="568"/>
-        <location filename="../../eWallet.cpp" line="634"/>
+        <location filename="../../eWallet.cpp" line="537"/>
+        <location filename="../../eWallet.cpp" line="570"/>
+        <location filename="../../eWallet.cpp" line="636"/>
         <source>ID Number</source>
         <translation>Identifiant</translation>
     </message>
     <message>
-        <location filename="../../eWallet.cpp" line="536"/>
-        <location filename="../../eWallet.cpp" line="543"/>
-        <location filename="../../eWallet.cpp" line="608"/>
-        <location filename="../../eWallet.cpp" line="627"/>
-        <location filename="../../eWallet.cpp" line="652"/>
+        <location filename="../../eWallet.cpp" line="538"/>
+        <location filename="../../eWallet.cpp" line="545"/>
+        <location filename="../../eWallet.cpp" line="610"/>
+        <location filename="../../eWallet.cpp" line="629"/>
+        <location filename="../../eWallet.cpp" line="654"/>
         <source>URL</source>
         <translation>URL</translation>
     </message>
     <message>
-        <location filename="../../eWallet.cpp" line="537"/>
-        <location filename="../../eWallet.cpp" line="557"/>
-        <location filename="../../eWallet.cpp" line="571"/>
-        <location filename="../../eWallet.cpp" line="646"/>
-        <location filename="../../eWallet.cpp" line="656"/>
+        <location filename="../../eWallet.cpp" line="539"/>
+        <location filename="../../eWallet.cpp" line="559"/>
+        <location filename="../../eWallet.cpp" line="573"/>
+        <location filename="../../eWallet.cpp" line="648"/>
+        <location filename="../../eWallet.cpp" line="658"/>
         <source>Card Notes</source>
         <translation>Notes</translation>
     </message>
     <message>
-        <location filename="../../eWallet.cpp" line="540"/>
-        <location filename="../../eWallet.cpp" line="645"/>
+        <location filename="../../eWallet.cpp" line="542"/>
+        <location filename="../../eWallet.cpp" line="647"/>
         <source>System</source>
         <translation>Système</translation>
     </message>
     <message>
-        <location filename="../../eWallet.cpp" line="546"/>
+        <location filename="../../eWallet.cpp" line="548"/>
         <source>Credit Card Type</source>
         <translation>Type</translation>
     </message>
     <message>
-        <location filename="../../eWallet.cpp" line="547"/>
+        <location filename="../../eWallet.cpp" line="549"/>
         <source>Card Provider</source>
         <translation>Organisme</translation>
     </message>
     <message>
-        <location filename="../../eWallet.cpp" line="548"/>
+        <location filename="../../eWallet.cpp" line="550"/>
         <source>Card Number</source>
         <translation>Numéro</translation>
     </message>
     <message>
-        <location filename="../../eWallet.cpp" line="549"/>
-        <location filename="../../eWallet.cpp" line="554"/>
-        <location filename="../../eWallet.cpp" line="651"/>
+        <location filename="../../eWallet.cpp" line="551"/>
+        <location filename="../../eWallet.cpp" line="556"/>
+        <location filename="../../eWallet.cpp" line="653"/>
         <source>Expiration Date</source>
         <translation>Expire le</translation>
     </message>
     <message>
-        <location filename="../../eWallet.cpp" line="550"/>
+        <location filename="../../eWallet.cpp" line="552"/>
         <source>Name on Card</source>
         <translation>Nom du porteur</translation>
     </message>
     <message>
-        <location filename="../../eWallet.cpp" line="552"/>
-        <location filename="../../eWallet.cpp" line="563"/>
+        <location filename="../../eWallet.cpp" line="554"/>
+        <location filename="../../eWallet.cpp" line="565"/>
         <source>PIN</source>
         <translation>Code personnel</translation>
     </message>
     <message>
-        <location filename="../../eWallet.cpp" line="553"/>
+        <location filename="../../eWallet.cpp" line="555"/>
         <source>Start Date</source>
         <translation>Mise en service le</translation>
     </message>
     <message>
-        <location filename="../../eWallet.cpp" line="555"/>
+        <location filename="../../eWallet.cpp" line="557"/>
         <source>Detail</source>
         <translation>Détail</translation>
     </message>
     <message>
-        <location filename="../../eWallet.cpp" line="556"/>
+        <location filename="../../eWallet.cpp" line="558"/>
         <source>3-digit CVC#</source>
         <translation>Cryptogramme</translation>
     </message>
     <message>
-        <location filename="../../eWallet.cpp" line="560"/>
+        <location filename="../../eWallet.cpp" line="562"/>
         <source>Bank Name</source>
         <translation>Nom de la banque</translation>
     </message>
     <message>
-        <location filename="../../eWallet.cpp" line="561"/>
+        <location filename="../../eWallet.cpp" line="563"/>
         <source>Account Number</source>
         <translation>Numéro de compte</translation>
     </message>
     <message>
-        <location filename="../../eWallet.cpp" line="562"/>
+        <location filename="../../eWallet.cpp" line="564"/>
         <source>Telephone</source>
         <translation>Téléphone</translation>
     </message>
     <message>
-        <location filename="../../eWallet.cpp" line="564"/>
+        <location filename="../../eWallet.cpp" line="566"/>
         <source>SWIFT Code</source>
         <translation>Code SWIFT</translation>
     </message>
     <message>
-        <location filename="../../eWallet.cpp" line="570"/>
-        <location filename="../../eWallet.cpp" line="635"/>
+        <location filename="../../eWallet.cpp" line="572"/>
+        <location filename="../../eWallet.cpp" line="637"/>
         <source>Card Title</source>
         <translation>Titre</translation>
     </message>
     <message>
-        <location filename="../../eWallet.cpp" line="574"/>
+        <location filename="../../eWallet.cpp" line="576"/>
         <source>Passport No</source>
         <translation>Numéro</translation>
     </message>
     <message>
-        <location filename="../../eWallet.cpp" line="575"/>
+        <location filename="../../eWallet.cpp" line="577"/>
         <source>Surname</source>
         <translation>Nom de famille</translation>
     </message>
     <message>
-        <location filename="../../eWallet.cpp" line="576"/>
+        <location filename="../../eWallet.cpp" line="578"/>
         <source>Given names</source>
         <translation>Prénoms</translation>
     </message>
     <message>
-        <location filename="../../eWallet.cpp" line="577"/>
+        <location filename="../../eWallet.cpp" line="579"/>
         <source>Date of birth</source>
         <translation>Date de naissance</translation>
     </message>
     <message>
-        <location filename="../../eWallet.cpp" line="578"/>
+        <location filename="../../eWallet.cpp" line="580"/>
         <source>Date of issue</source>
         <translation>Délivré le</translation>
     </message>
     <message>
-        <location filename="../../eWallet.cpp" line="579"/>
+        <location filename="../../eWallet.cpp" line="581"/>
         <source>Date of expiration</source>
         <translation>Expire le</translation>
     </message>
     <message>
-        <location filename="../../eWallet.cpp" line="580"/>
+        <location filename="../../eWallet.cpp" line="582"/>
         <source>Authority</source>
         <translation>Délivré par</translation>
     </message>
     <message>
-        <location filename="../../eWallet.cpp" line="583"/>
+        <location filename="../../eWallet.cpp" line="585"/>
         <source>Text</source>
         <translation>Texte</translation>
     </message>
     <message>
-        <location filename="../../eWallet.cpp" line="586"/>
-        <location filename="../../eWallet.cpp" line="590"/>
+        <location filename="../../eWallet.cpp" line="588"/>
+        <location filename="../../eWallet.cpp" line="592"/>
         <source>Model</source>
         <translation>Modèle</translation>
     </message>
     <message>
-        <location filename="../../eWallet.cpp" line="587"/>
+        <location filename="../../eWallet.cpp" line="589"/>
         <source>Vehicle Number</source>
         <translation>Immatriculation</translation>
     </message>
     <message>
-        <location filename="../../eWallet.cpp" line="591"/>
+        <location filename="../../eWallet.cpp" line="593"/>
         <source>Brand</source>
         <translation>Marque</translation>
     </message>
     <message>
-        <location filename="../../eWallet.cpp" line="592"/>
+        <location filename="../../eWallet.cpp" line="594"/>
         <source>IMEI#</source>
         <translation>IMEI#</translation>
     </message>
     <message>
-        <location filename="../../eWallet.cpp" line="593"/>
+        <location filename="../../eWallet.cpp" line="595"/>
         <source>Firmware code</source>
         <translation>Code du firmware </translation>
     </message>
     <message>
-        <location filename="../../eWallet.cpp" line="594"/>
+        <location filename="../../eWallet.cpp" line="596"/>
         <source>Purchased</source>
         <translation>Acheté le</translation>
     </message>
     <message>
-        <location filename="../../eWallet.cpp" line="595"/>
+        <location filename="../../eWallet.cpp" line="597"/>
         <source>Pin1</source>
         <translation>Code personnel 1</translation>
     </message>
     <message>
-        <location filename="../../eWallet.cpp" line="596"/>
+        <location filename="../../eWallet.cpp" line="598"/>
         <source>Pin2</source>
         <translation>Code personnel 2</translation>
     </message>
     <message>
-        <location filename="../../eWallet.cpp" line="597"/>
+        <location filename="../../eWallet.cpp" line="599"/>
         <source>Puk1</source>
         <translation>Clé de déblocage 1</translation>
     </message>
     <message>
-        <location filename="../../eWallet.cpp" line="598"/>
+        <location filename="../../eWallet.cpp" line="600"/>
         <source>Puk2</source>
         <translation>Clé de déblocage 2</translation>
     </message>
     <message>
-        <location filename="../../eWallet.cpp" line="599"/>
+        <location filename="../../eWallet.cpp" line="601"/>
         <source>Num SIM</source>
         <translation>Numéro carte SIM</translation>
     </message>
     <message>
-        <location filename="../../eWallet.cpp" line="602"/>
+        <location filename="../../eWallet.cpp" line="604"/>
         <source>Manufacturer</source>
         <translation>Fabricant</translation>
     </message>
     <message>
-        <location filename="../../eWallet.cpp" line="605"/>
-        <location filename="../../eWallet.cpp" line="619"/>
+        <location filename="../../eWallet.cpp" line="607"/>
+        <location filename="../../eWallet.cpp" line="621"/>
         <source>Product</source>
         <translation>Produit</translation>
     </message>
     <message>
-        <location filename="../../eWallet.cpp" line="606"/>
+        <location filename="../../eWallet.cpp" line="608"/>
         <source>Version</source>
         <translation>Version</translation>
     </message>
     <message>
-        <location filename="../../eWallet.cpp" line="607"/>
-        <location filename="../../eWallet.cpp" line="620"/>
+        <location filename="../../eWallet.cpp" line="609"/>
+        <location filename="../../eWallet.cpp" line="622"/>
         <source>Serial #</source>
         <translation>Numéro de série</translation>
     </message>
     <message>
-        <location filename="../../eWallet.cpp" line="609"/>
+        <location filename="../../eWallet.cpp" line="611"/>
         <source>Company</source>
         <translation>Compagnie</translation>
     </message>
     <message>
-        <location filename="../../eWallet.cpp" line="610"/>
+        <location filename="../../eWallet.cpp" line="612"/>
         <source>Date bought</source>
         <translation>Acheté le</translation>
     </message>
     <message>
-        <location filename="../../eWallet.cpp" line="611"/>
+        <location filename="../../eWallet.cpp" line="613"/>
         <source>Username</source>
         <translation>Nom utilisateur</translation>
     </message>
     <message>
-        <location filename="../../eWallet.cpp" line="612"/>
-        <location filename="../../eWallet.cpp" line="628"/>
+        <location filename="../../eWallet.cpp" line="614"/>
+        <location filename="../../eWallet.cpp" line="630"/>
         <source>Login</source>
         <translation>Identifiant</translation>
     </message>
     <message>
-        <location filename="../../eWallet.cpp" line="613"/>
+        <location filename="../../eWallet.cpp" line="615"/>
         <source>Authorization key</source>
         <translation>Clé d&apos;autorisation</translation>
     </message>
     <message>
-        <location filename="../../eWallet.cpp" line="614"/>
-        <location filename="../../eWallet.cpp" line="623"/>
+        <location filename="../../eWallet.cpp" line="616"/>
+        <location filename="../../eWallet.cpp" line="625"/>
         <source>Price paid</source>
         <translation>Tarif</translation>
     </message>
     <message>
-        <location filename="../../eWallet.cpp" line="615"/>
+        <location filename="../../eWallet.cpp" line="617"/>
         <source>Support</source>
         <translation>Support</translation>
     </message>
     <message>
-        <location filename="../../eWallet.cpp" line="616"/>
-        <location filename="../../eWallet.cpp" line="631"/>
+        <location filename="../../eWallet.cpp" line="618"/>
+        <location filename="../../eWallet.cpp" line="633"/>
         <source>Notes</source>
         <translation>Notes</translation>
     </message>
     <message>
-        <location filename="../../eWallet.cpp" line="621"/>
+        <location filename="../../eWallet.cpp" line="623"/>
         <source>Model #</source>
         <translation>Modèle</translation>
     </message>
     <message>
-        <location filename="../../eWallet.cpp" line="622"/>
+        <location filename="../../eWallet.cpp" line="624"/>
         <source>Bought from</source>
         <translation>Acheté le</translation>
     </message>
     <message>
-        <location filename="../../eWallet.cpp" line="624"/>
+        <location filename="../../eWallet.cpp" line="626"/>
         <source>Guarantee period</source>
         <translation>Fin de garantie</translation>
     </message>
     <message>
-        <location filename="../../eWallet.cpp" line="630"/>
+        <location filename="../../eWallet.cpp" line="632"/>
         <source>E mail used</source>
         <translation>Email utilisé</translation>
     </message>
     <message>
-        <location filename="../../eWallet.cpp" line="638"/>
+        <location filename="../../eWallet.cpp" line="640"/>
         <source>Social Security Number</source>
         <translation>Numéro de sécurité sociale</translation>
     </message>
     <message>
-        <location filename="../../eWallet.cpp" line="639"/>
+        <location filename="../../eWallet.cpp" line="641"/>
         <source>Name</source>
         <translation>Nom</translation>
     </message>
     <message>
-        <location filename="../../eWallet.cpp" line="649"/>
+        <location filename="../../eWallet.cpp" line="651"/>
         <source>Driver&apos;s License Number</source>
         <translation>Numéro</translation>
     </message>
     <message>
-        <location filename="../../eWallet.cpp" line="650"/>
+        <location filename="../../eWallet.cpp" line="652"/>
         <source>Date Issued</source>
         <translation>Délivré le</translation>
     </message>
     <message>
-        <location filename="../../eWallet.cpp" line="907"/>
+        <location filename="../../eWallet.cpp" line="909"/>
         <source>About</source>
         <translation>A propos de</translation>
     </message>
     <message>
-        <location filename="../../eWallet.cpp" line="909"/>
+        <location filename="../../eWallet.cpp" line="911"/>
         <source>Delete DB</source>
         <translation>Supprimer BDD</translation>
     </message>
     <message>
-        <location filename="../../eWallet.cpp" line="911"/>
-        <location filename="../../eWallet.cpp" line="922"/>
+        <location filename="../../eWallet.cpp" line="913"/>
+        <location filename="../../eWallet.cpp" line="924"/>
         <source>Exit</source>
         <translation>Quitter</translation>
     </message>
     <message>
-        <location filename="../../eWallet.cpp" line="914"/>
+        <location filename="../../eWallet.cpp" line="916"/>
         <source>New</source>
         <translation>Nouveau</translation>
     </message>
     <message>
-        <location filename="../../eWallet.cpp" line="916"/>
-        <location filename="../../eWallet.cpp" line="1390"/>
+        <location filename="../../eWallet.cpp" line="918"/>
+        <location filename="../../eWallet.cpp" line="1392"/>
         <source>Edit</source>
         <translation>Editer</translation>
     </message>
     <message>
-        <location filename="../../eWallet.cpp" line="917"/>
+        <location filename="../../eWallet.cpp" line="919"/>
         <source>Invert Sort</source>
         <translation>Tri inversé</translation>
     </message>
     <message>
-        <location filename="../../eWallet.cpp" line="918"/>
+        <location filename="../../eWallet.cpp" line="920"/>
         <source>Import</source>
         <translation>Importer</translation>
     </message>
     <message>
-        <location filename="../../eWallet.cpp" line="919"/>
+        <location filename="../../eWallet.cpp" line="921"/>
         <source>Export</source>
         <translation>Exporter</translation>
     </message>
     <message>
-        <location filename="../../eWallet.cpp" line="921"/>
+        <location filename="../../eWallet.cpp" line="923"/>
         <source>Change Password</source>
         <translation>Changer le mot de passe</translation>
     </message>
     <message>
-        <location filename="../../eWallet.cpp" line="981"/>
+        <location filename="../../eWallet.cpp" line="983"/>
         <source>Are you sure you want to remove it?</source>
         <translation>Etes-vous sûr de vouloir le supprimer ?</translation>
     </message>
     <message>
-        <location filename="../../eWallet.cpp" line="1129"/>
+        <location filename="../../eWallet.cpp" line="1131"/>
         <source>Choose import file</source>
         <translation>Choisir le fichier d&apos;import</translation>
     </message>
     <message>
-        <location filename="../../eWallet.cpp" line="1131"/>
-        <location filename="../../eWallet.cpp" line="1409"/>
+        <location filename="../../eWallet.cpp" line="1133"/>
+        <location filename="../../eWallet.cpp" line="1411"/>
         <source>Text files (*.txt);;</source>
         <translation>Fichiers texte (*.txt)</translation>
     </message>
     <message>
-        <location filename="../../eWallet.cpp" line="1379"/>
+        <location filename="../../eWallet.cpp" line="1381"/>
         <source>Rename</source>
         <translation>Renommer</translation>
     </message>
     <message>
-        <location filename="../../eWallet.cpp" line="1380"/>
-        <location filename="../../eWallet.cpp" line="1393"/>
+        <location filename="../../eWallet.cpp" line="1382"/>
+        <location filename="../../eWallet.cpp" line="1395"/>
         <source>Delete</source>
         <translation>Effacer</translation>
     </message>
     <message>
-        <location filename="../../eWallet.cpp" line="1389"/>
+        <location filename="../../eWallet.cpp" line="1391"/>
         <source>View</source>
         <translation>Voir</translation>
     </message>
     <message>
-        <location filename="../../eWallet.cpp" line="1391"/>
+        <location filename="../../eWallet.cpp" line="1393"/>
         <source>New like this</source>
         <translation>Nouveau comme celui-ci</translation>
     </message>
     <message>
-        <location filename="../../eWallet.cpp" line="1392"/>
+        <location filename="../../eWallet.cpp" line="1394"/>
         <source>Duplicate</source>
         <translation>Dupliquer</translation>
     </message>
     <message>
-        <location filename="../../eWallet.cpp" line="1407"/>
+        <location filename="../../eWallet.cpp" line="1409"/>
         <source>Choose export file</source>
         <translation>Choisir fichier d&apos;export</translation>
     </message>
     <message>
-        <location filename="../../eWallet.cpp" line="1615"/>
+        <location filename="../../eWallet.cpp" line="1617"/>
         <source>About Wallet</source>
         <translation>A propos de Wallet</translation>
     </message>
     <message>
-        <location filename="../../eWallet.cpp" line="1615"/>
+        <location filename="../../eWallet.cpp" line="1617"/>
         <source>&lt;qt&gt;&lt;br&gt;&lt;br&gt;&lt;p&gt;&lt;i&gt;&lt;b&gt;qtWallet&lt;/b&gt;&lt;/i&gt;, v.1.0&lt;/p&gt;&lt;p&gt;Developed by &lt;b&gt;nowheremanmail@gmail.com&lt;/b&gt;&lt;/p&gt;&lt;p&gt;Icons by http://pixelmixer.ru/&lt;/p&gt;&lt;p&gt;if you think that qtWallet is useful for you, please&lt;/p&gt;&lt;a href=&quot;https://www.paypal.com/cgi-bin/webscr?cmd=_donations&amp;business=nowheremanmail@gmail.com&amp;lc=US&amp;item_name=qtWallet&amp;currency_code=EUR&amp;bn=PP%2dDonationsBF%3abtn_donate_SM%2egif%3aNonHosted&quot;&gt;DONATE&lt;/a&gt;&lt;/qt&gt;</source>
-        <translation type="unfinished"></translation>
+        <translation>&lt;qt&gt;&lt;br&gt;&lt;br&gt;&lt;p&gt;&lt;i&gt;&lt;b&gt;Wallet&lt;/b&gt;&lt;/i&gt;, v.%1&lt;/p&gt;&lt;p&gt;Desarrollado por &lt;b&gt;nowheremanmail@gmail.com&lt;/b&gt;&lt;/p&gt;&lt;p&gt;Iconos por http://pixelmixer.ru/&lt;/p&gt;&lt;p&gt;Si piensas que Wallet es util para ti, puedes &lt;/p&gt;&lt;a href=&quot;https://www.paypal.com/cgi-bin/webscr?cmd=_donations&amp;business=nowheremanmail@gmail.com&amp;lc=US&amp;item_name=qtWallet&amp;currency_code=EUR&amp;bn=PP%2dDonationsBF%3abtn_donate_SM%2egif%3aNonHosted&quot;&gt;DONAR&lt;/a&gt;&lt;/qt&gt;</translation>
     </message>
     <message>
-        <location filename="../../eWallet.cpp" line="1654"/>
+        <location filename="../../eWallet.cpp" line="1656"/>
         <source>Changing password, please wait until application quits</source>
         <translation>Changement du mot de passe en cours, patientez SVP que l&apos;application se ferme</translation>
     </message>
     <message>
-        <location filename="../../eWallet.cpp" line="1660"/>
+        <location filename="../../eWallet.cpp" line="1662"/>
         <source>Password changed successfully, application will exit</source>
         <translation>Mot de passe modifié avec succès, l&apos;application va se fermer</translation>
     </message>
     <message>
-        <location filename="../../eWallet.cpp" line="1662"/>
+        <location filename="../../eWallet.cpp" line="1664"/>
         <source>Password CANNOT BE changed, because %1, and application will exit</source>
         <translation>Le mot de passe ne peut être modifié, parce que %1 et l&apos;application va se fermer</translation>
     </message>
