@@ -1,6 +1,8 @@
 #ifndef CONSTANTS_H
 #define CONSTANTS_H
 
+#ifdef Q_WS_MAEMO_5
+
 #define SMALL_WIDTH 100
 #define SMALL_HEIGH (SMALL_WIDTH * 5398 / 8660)
 
@@ -10,11 +12,30 @@
 #define MAX_WIDTH 780
 #define MAX_HEIGH (MAX_WIDTH * 5398 / 8660)
 
+// Landscape
 #define MAX_WIDTH_L 460
 #define MAX_HEIGH_L (MAX_WIDTH_L * 5398 / 8660)
 
+#else
+
+#define SMALL_WIDTH 100
+#define SMALL_HEIGH (SMALL_WIDTH * 5398 / 8660)
+
+#define BIG_WIDTH 350
+#define BIG_HEIGH (BIG_WIDTH * 5398 / 8660)
+
+#define MAX_WIDTH 350
+#define MAX_HEIGH (MAX_WIDTH * 5398 / 8660)
+
+#define WINDOW_WIDTH 800
+#define WINDOW_HEIGHT 500
+
+#endif
+
+// internal image size
 #define INTERNAL_WIDTH 400
 #define INTERNAL_HEIGH (INTERNAL_WIDTH * 5398 / 8660)
+
 #define B_SIZE 105
 #define KEY_SIZE 16
 
