@@ -2,15 +2,18 @@
  * Copyright (c) 2010 David Galindo <nowheremanmail@gmail.com>
  *
  *
- * libhildonmm-dev   libhildon1-dev libhildonnotify-dev libhildonnotifymm-dev libhildonmm-dev
  */
 
+
 #include "utils.h"
 
+
 #include "eWallet.h"
 #include "Constants.h"
 #include "DetailedWindow.h"
 #include <Qt>
+#include <QDBusInterface>
+#include <QDBusConnection>
 #include <QDesktopServices>
 //#include <QAbstractKineticScroller>
 
@@ -32,17 +35,48 @@ public:
 	}
 protected:
 	bool isLabel;
-    void mousePressEvent(QMouseEvent *ev) {
+    void mousePressEvent(QMouseEvent *) {
     	////qDebug () << "click on field " << this->userData(0);
     	TargetField * f = ((ButtonInfo *)this->userData(0))->field;
     	if (f->type == TYPE_URL && !isLabel) {
     		QDesktopServices::openUrl(QUrl::fromUserInput(f->value));
     	}
     	else {
-			//if (f != NULL)
-			////qDebug () << "pressed " << f->value;
-			QClipboard *cb = QApplication::clipboard();
-			cb->setText(f->value);
+    		if (!isLabel) {
+    			if (f->type == TYPE_PHONE_NUMBER) {
+//    				QDBusConnection conn = QDBusConnection::systemBus(); //QString(MCE_SERVICE), QString(MCE_SIGNAL_PATH)
+//    				QDBusInterface dbusPhone( "com.nokia.csd.Call", "/com/nokia/csd/call", "com.nokia.csd.Call", conn );
+//    				QDBusMessage msg = dbusPhone.call( "CreateWith", f->value, (uint)0 );
+
+    				QDBusMessage msg = QDBusMessage::createMethodCall(
+    				        "com.nokia.csd.Call", // --dest
+    				        "/com/nokia/csd/call", // destination object path
+    				        "com.nokia.csd.Call", // message name (w/o method)
+    				        "CreateWith" // method
+    				    );
+    				msg << f->value;
+    				msg << 0;
+    				msg = QDBusConnection::systemBus().call(msg);
+
+    				qDebug() << msg;
+
+    				    //    			dbus-send --system --type=method_call --print-reply --dest=com.nokia.csd.Call /com/nokia/csd/call com.nokia.csd.Call.CreateWith string:"$NUMBER" uint32:0
+    			}
+    			else {
+#ifdef Q_WS_MAEMO_5
+    				show_banner(this, tr("%1 has been saved to clipboard").arg(f->name));
+#endif
+					QClipboard *cb = QApplication::clipboard();
+					cb->setText(f->value);
+    			}
+    		}
+    		else {
+#ifdef Q_WS_MAEMO_5
+    			show_banner(this, tr("%1 has been saved to clipboard").arg(f->name));
+#endif
+ 				QClipboard *cb = QApplication::clipboard();
+				cb->setText(f->value);
+    		}
     	}
     }
 };
@@ -54,10 +88,17 @@ DetailWindow::DetailWindow(Target * _target, const QString & groupName, int iste
 
 	setWindowTitle("Wallet");
 
+#ifdef Q_WS_MAEMO_5
 	this->setAttribute(Qt::WA_Maemo5StackedWindow);
+
 	if (!edit)
 		connect(QApplication::desktop(), SIGNAL(resized(int)), this, SLOT(orientationChanged(int)));
 
+	this->setAttribute(Qt::WA_Maemo5ShowProgressIndicator, true);
+#else
+	this->setMinimumSize(WINDOW_WIDTH, WINDOW_HEIGHT);
+#endif
+
 	forceClose = false;
 
 	isNew = istemplate > 0 || _target == NULL;
@@ -70,7 +111,6 @@ DetailWindow::DetailWindow(Target * _target, const QString & groupName, int iste
 
 	//qDebug () << "DETAIL " << target << " " << groupName << " " << istemplate << " " << edit;
 
-	this->setAttribute(Qt::WA_Maemo5ShowProgressIndicator, true);
 
 	if (istemplate > 0) {
 		this->target = new Target ();
@@ -122,6 +162,7 @@ DetailWindow::DetailWindow(Target * _target, const QString & groupName, int iste
 
 
 	if (edit) {
+#ifdef Q_WS_MAEMO_5
 		menuBar()->addAction(tr("Save"), this, SLOT(saveTarget()));
 		if (!isNew)
 			menuBar()->addAction(tr("Delete"), this, SLOT(_deleteTarget()));
@@ -132,18 +173,46 @@ DetailWindow::DetailWindow(Target * _target, const QString & groupName, int iste
 		menuBar()->addAction(tr("Delete Face Pict."), this, SLOT(deleteCardFace()));
 		menuBar()->addAction(tr("Delete Back Pict."), this, SLOT(deleteCardBack()));
 		menuBar()->addAction(tr("Modify fields"), this, SLOT(modifyFields()));
+#else
+		QMenu * m = menuBar()->addMenu(tr("Card"));
+		m->addAction(tr("Save"), this, SLOT(saveTarget()));
+		if (!isNew)
+			m->addAction(tr("Delete"), this, SLOT(_deleteTarget()));
+		m = menuBar()->addMenu(tr("Pictures"));
+		m->addAction(tr("Change Face Pict."), this, SLOT(cardFace()));
+		m->addAction(tr("Mirror Face Pict."), this, SLOT(mirrorFace()));
+		m->addAction(tr("Delete Face Pict."), this, SLOT(deleteCardFace()));
+		m->addSeparator ();
+		m->addAction(tr("Change Back Pict."), this, SLOT(cardBack()));
+		m->addAction(tr("Mirror Back Pict."), this, SLOT(mirrorBack()));
+		m->addAction(tr("Delete Back Pict."), this, SLOT(deleteCardBack()));
+		m = menuBar()->addMenu(tr("Others"));
+		m->addAction(tr("Modify fields"), this, SLOT(modifyFields()));
+#endif
 
 #ifdef CAMERA
 		menuBar()->addAction(tr("Camera"), this, SLOT(takePicture()));
 #endif
 	}
 	else {
+#ifdef Q_WS_MAEMO_5
 		menuBar()->addAction(tr("New Card"), this, SLOT(_newTarget()));
 		menuBar()->addAction(tr("Edit Card"), this, SLOT(_editTarget()));
 		menuBar()->addAction(tr("New Card like this"), this, SLOT(_newLikeTarget()));
 		menuBar()->addAction(tr("Duplicate Card"), this, SLOT(_duplicateTarget()));
 		menuBar()->addAction(tr("Export Face Pict."), this, SLOT(exportCardFace()));
 		menuBar()->addAction(tr("Export Back Pict."), this, SLOT(exportCardBack()));
+#else
+		QMenu * m = menuBar()->addMenu(tr("Card"));
+		m->addAction(tr("New Card"), this, SLOT(_newTarget()));
+		m->addAction(tr("Edit Card"), this, SLOT(_editTarget()));
+		m->addAction(tr("New Card like this"), this, SLOT(_newLikeTarget()));
+		m->addAction(tr("Duplicate Card"), this, SLOT(_duplicateTarget()));
+
+		m = menuBar()->addMenu(tr("Pictures"));
+		m->addAction(tr("Export Face Pict."), this, SLOT(exportCardFace()));
+		m->addAction(tr("Export Back Pict."), this, SLOT(exportCardBack()));
+#endif
 	}
 	
 	centralWidget = new QWidget(this);
@@ -301,12 +370,15 @@ DetailWindow::DetailWindow(Target * _target, const QString & groupName, int iste
 		
 		//imageLabel->setContextMenuPolicy(Qt::CustomContextMenu);
 		//QObject::connect(imageLabel, SIGNAL(customContextMenuRequested(const QPoint&)), this, SLOT(cardFaceMenu(const QPoint&)));
-
+#ifdef Q_WS_MAEMO_5
 		if (edit) {
-			componentLayout->addWidget(imageLabel, 3, 1, 2, 3);
+			componentLayout->addWidget(imageLabel, 3, 0, 2, 3);
 		}
 		else
 			vboxlayout->addWidget(imageLabel); //, 0, 0, 1, 1);
+#else
+		componentLayout->addWidget(imageLabel, 3, 0, 2, 3);
+#endif
 	}
 	else {
 		imageLabel = NULL;
@@ -340,21 +412,30 @@ DetailWindow::DetailWindow(Target * _target, const QString & groupName, int iste
 		//imageBackLabel->setContextMenuPolicy(Qt::CustomContextMenu);
 		//QObject::connect(imageBackLabel, SIGNAL(customContextMenuRequested(const QPoint&)), this, SLOT(cardBackMenu(const QPoint&)));
 
+#ifdef Q_WS_MAEMO_5
 		if (edit) {
-			componentLayout->addWidget(imageBackLabel, 3, 4, 2, 3);
+			componentLayout->addWidget(imageBackLabel, 3, 3, 2, 3);
 		}
 		else
 			vboxlayout->addWidget(imageBackLabel); //, 1, 0, 1, 1);
+#else
+		componentLayout->addWidget(imageBackLabel, 3, 3, 2, 3);
+#endif
 	}
 	else {
 		imageBackLabel = NULL;
 	}
 
+#ifdef Q_WS_MAEMO_5
 	if (edit) {
 		vboxlayout->addLayout(componentLayout);
 		componentLayout = new QGridLayout ();
 		//componentLayout->setSpacing(5);
 	}
+#else
+	vboxlayout->addLayout(componentLayout);
+	componentLayout = new QGridLayout ();
+#endif
 
 	componentLayout->setColumnMinimumWidth(1, 100);
 
@@ -368,9 +449,10 @@ DetailWindow::DetailWindow(Target * _target, const QString & groupName, int iste
 		QObject::connect(saveButton, SIGNAL(clicked()), this, SLOT(saveTarget()));
 	}
 
+#ifdef Q_WS_MAEMO_5
 	this->setAttribute(Qt::WA_Maemo5ShowProgressIndicator, false);
-
 	orientationChanged(0);
+#endif
 
 	if (edit) {
 		centralWidget->setFocus ();
@@ -671,30 +753,38 @@ DetailWindow::~DetailWindow () {
 
 void DetailWindow::saveTarget () {
 	if (nameLineEdit->text().length() < 1) {
+#ifdef Q_WS_MAEMO_5
 		show_information_note (NULL, tr("Card description is missing"));
-//		if (messageBox.isNull()) {
-//			hildon_banner_show_information((GtkWidget *)this->nativeParentWidget(), NULL, "HELLO CAMERA");
-//
-//			messageBox = new QMessageBox(this);
-//			messageBox->information(this, "Wallet", tr("Card description is missing"), QMessageBox::Ok);
-//		}
-//		delete messageBox;
-//		messageBox = 0;
+#endif
+#ifndef Q_WS_MAEMO_5
+		if (messageBox.isNull()) {
+			messageBox = new QMessageBox(this);
+			messageBox->information(this, "Wallet", tr("Card description is missing"), QMessageBox::Ok);
+		}
+		delete messageBox;
+		messageBox = 0;
+#endif
 		return;
 	}
 
 	 if (typeLineEdit->currentIndex() < 0) {
-		show_information_note (NULL, tr("Type card is missing"));
-//		if (messageBox.isNull()) {
-//			messageBox = new QMessageBox(this);
-//			messageBox->information(this, "Wallet", tr("Type card is missing"), QMessageBox::Ok);
-//		}
-//		delete messageBox;
-//		messageBox = 0;
+#ifdef Q_WS_MAEMO_5
+		 show_information_note (NULL, tr("Type card is missing"));
+#endif
+#ifndef Q_WS_MAEMO_5
+		if (messageBox.isNull()) {
+			messageBox = new QMessageBox(this);
+			messageBox->information(this, "Wallet", tr("Type card is missing"), QMessageBox::Ok);
+		}
+		delete messageBox;
+		messageBox = 0;
+#endif
 		return;
 	}
 	
+#ifdef Q_WS_MAEMO_5
 	this->setAttribute(Qt::WA_Maemo5ShowProgressIndicator, true);
+#endif
 
 	if (target == NULL) {
 		this->target = new Target ();
@@ -769,7 +859,9 @@ void DetailWindow::saveTarget () {
 
 	//qDebug () << "clse ";
 
+#ifdef Q_WS_MAEMO_5
 	this->setAttribute(Qt::WA_Maemo5ShowProgressIndicator, false);
+#endif
 
 	forceClose = true;
 
@@ -784,13 +876,17 @@ void DetailWindow::forceclose () {
 }
 
 void DetailWindow::_deleteTarget () {
+#ifdef Q_WS_MAEMO_5
 	this->setAttribute(Qt::WA_Maemo5ShowProgressIndicator, true);
+#endif
 
 	if (target) {
 		parent->deleteTarget(target);
 	}
 
+#ifdef Q_WS_MAEMO_5
 	this->setAttribute(Qt::WA_Maemo5ShowProgressIndicator, false);
+#endif
 
 	forceClose = true;
 	close();
@@ -995,6 +1091,7 @@ void DetailWindow::mirrorBack () {
 //	menu.exec(pos);
 //}
 
+
 void DetailWindow::orientationChanged(int o) {
 	////qDebug () << "CHAGNED";
 
@@ -1023,6 +1120,7 @@ void DetailWindow::orientationChanged(int o) {
 	}
 }
 
+
 void DetailWindow::deleteCardBack()
 {
 	QPixmap available(":/resources/empty_card_back.png");
