@@ -17,14 +17,15 @@
  */
 
 #include "utils.h"
+#include <QDBusInterface>
+#include <QDBusConnection>
+
 #include "eWallet.h"
 #include "Constants.h"
 #include "DatabaseManager.h"
 #include <Qt>
 #include <QtGui>
 #include <QFile>
-#include <QDBusInterface>
-#include <QDBusConnection>
 #include <QDesktopServices>
 #include <QListView>
 
@@ -120,10 +121,14 @@ eWallet::eWallet(QString * group, eWallet * _parent, QWidget *parent) : QMainWin
 	centralWidget = NULL;
 	currentGroup = group;
 
+#ifdef Q_WS_MAEMO_5
 	this->setAttribute(Qt::WA_Maemo5AutoOrientation, true);
 	//connect(QApplication::desktop(), SIGNAL(resized(int)), this, SLOT(orientationChanged(int)));
 
 	this->setAttribute(Qt::WA_Maemo5StackedWindow);
+#else
+	this->setMinimumSize(WINDOW_WIDTH, WINDOW_HEIGHT);
+#endif
 
 	ascSort = true;
 	currentFilter = "";
@@ -147,10 +152,14 @@ eWallet::eWallet(QWidget *parent) : QMainWindow(parent)
 	centralWidget = NULL;
 	isShowGroups = 0;
 
+#ifdef Q_WS_MAEMO_5
 	this->setAttribute(Qt::WA_Maemo5AutoOrientation, true);
 	connect(QApplication::desktop(), SIGNAL(resized(int)), this, SLOT(orientationChanged(int)));
 
 	this->setAttribute(Qt::WA_Maemo5StackedWindow);
+#else
+	this->setMinimumSize(WINDOW_WIDTH, WINDOW_HEIGHT);
+#endif
 
 	ascSort = true;
 	currentFilter = "";
@@ -161,16 +170,20 @@ eWallet::eWallet(QWidget *parent) : QMainWindow(parent)
 
 	askPassword ();
 
+#ifdef Q_WS_MAEMO_5
 	QDBusConnection conn = QDBusConnection::systemBus(); //QString(MCE_SERVICE), QString(MCE_SIGNAL_PATH)
 	bool success = conn.connect("","", QString("com.nokia.mce.signal"/*MCE_SIGNAL_IF*/), QString("display_status_ind"/*MCE_DISPLAY_SIG*/) , this, SLOT(listenInactivity(QString)));
 	//bool success = conn.connect("","", QString(MCE_SIGNAL_IF), QString(MCE_DISPLAY_SIG) , this, SLOT(listenInactivity(QString)));
+#endif
 }
 
+
 void eWallet::orientationChanged(int o) {
 	if (isAskPassword) {
 		loginDialogDlg->orientationChanged (o);
 	}
 }
+
 void eWallet::showList () {
 	//qDebug () << "going to showList";
 
@@ -303,6 +316,15 @@ void eWallet::changeMode () {
 //}
 
 void eWallet::selectItem(QListWidgetItem * item) {
+	if (!(extraWindow.isNull() && detailWindow.isNull() && detailWindowEdit.isNull())) {
+		if (!extraWindow.isNull()) extraWindow->raise();
+		else
+		if (!detailWindow.isNull()) detailWindow->raise();
+		else
+		if (!detailWindowEdit.isNull()) detailWindowEdit->raise();
+		return ;
+	}
+
 	if (isShowGroups == 1) {
 		if (fnListWidget->currentItem() != item) {
 			fnListWidget->setCurrentItem(item);
@@ -318,7 +340,6 @@ void eWallet::selectItem(QListWidgetItem * item) {
 
 		if (extraWindow.isNull()) {
 			extraWindow = new eWallet(_target, this, this);
-			//extraWindow->setAttribute(Qt::WA_Maemo5StackedWindow);
 			extraWindow->setAttribute(Qt::WA_DeleteOnClose);
 	        connect(extraWindow, SIGNAL(destroyed(QObject*)),
 	                this, SLOT(windowDestroyedExtra(QObject*)));
@@ -485,13 +506,17 @@ bool eWallet::openDataBase (const QString & pas)
 		}
 		else {
 			if (!::dbManager->isReady ()) {
+#ifdef Q_WS_MAEMO_5
 				show_banner (this, tr("Wrong password"));
-//				if (messageBox.isNull()) {
-//					messageBox = new QMessageBox(this);
-//					messageBox->information(this, "Wallet", tr("Wrong password"), QMessageBox::Ok);
-//				}
-//				delete messageBox;
-//				messageBox = 0;
+#endif
+#ifndef Q_WS_MAEMO_5
+				if (messageBox.isNull()) {
+					messageBox = new QMessageBox(this);
+					messageBox->information(this, "Wallet", tr("Wrong password"), QMessageBox::Ok);
+				}
+				delete messageBox;
+				messageBox = 0;
+#endif
 			}
 		}
 	}
@@ -834,10 +859,11 @@ void eWallet::showGroups(bool reset)
 	else
 		qSort (grouplist.begin(),grouplist.end(),sortStringDES);
 
-	//fnListWidget->setIconSize (QSize (SMALL_WIDTH, SMALL_HEIGH));
-	//fnListWidget->setContentsMargins(10, 1, 0, 1);
+//	fnListWidget->setIconSize (QSize (SMALL_WIDTH, SMALL_HEIGH));
+//	fnListWidget->setContentsMargins(10, 1, 0, 1);
 
 	QListWidgetItem* listitem = new QListWidgetItem(tr("<All>"), fnListWidget);
+
 	//listitem->set(target->getSummary());
 	fnListWidget->addItem(listitem);
 
@@ -877,8 +903,9 @@ void eWallet::showInfo(bool reset) {
 
 void eWallet::showTargets(bool reset, const QString * filter)
 {
+#ifdef Q_WS_MAEMO_5
 	this->setAttribute(Qt::WA_Maemo5ShowProgressIndicator, true);
-
+#endif
 	//qDebug () << "show Targets " << reset;
 
 	int current = fnListWidget->currentRow();
@@ -917,13 +944,15 @@ void eWallet::showTargets(bool reset, const QString * filter)
 
 	update();
 
+#ifdef Q_WS_MAEMO_5
 	this->setAttribute(Qt::WA_Maemo5ShowProgressIndicator, false);
+#endif
 }
 
 void eWallet::createMenu()
 {
 	//qDebug () << "create Menu " << isAskPassword;
-
+#ifdef Q_WS_MAEMO_5
 	menuBar()->clear();
 	if (isAskPassword) {
 		menuBar()->addAction(tr("About"), this, SLOT(about()));
@@ -943,6 +972,32 @@ void eWallet::createMenu()
 		menuBar()->addAction(tr("Change Password"), this, SLOT(changePassword()));
 		menuBar()->addAction(tr("Exit"), QApplication::instance(), SLOT(quit()));
 	}
+#else
+	menuBar()->clear();
+	if (isAskPassword) {
+		menuBar()->addAction(tr("Exit"), QApplication::instance(), SLOT(quit()));
+		menuBar()->addAction(tr("About"), this, SLOT(about()));
+//		if (!isChangingPassword) {
+//			menuBar()->addAction(tr("Delete DB"), this, SLOT(deleteDB()));
+//		}
+	}
+	else {
+		QMenu * m = menuBar()->addMenu(tr("Card"));
+		m->addAction(tr("New"), this, SLOT(newTarget()));
+		if (isShowGroups == 2)
+			m->addAction(tr("Edit"), this, SLOT(_editcTarget()));
+		m->addSeparator();
+		m->addAction(tr("Invert Sort"), this, SLOT(sort()));
+		m->addSeparator();
+		m->addAction(tr("Change Password"), this, SLOT(changePassword()));
+		m->addSeparator();
+		m->addAction(tr("Import"), this, SLOT(import()));
+		m->addAction(tr("Export"), this, SLOT(exportData()));
+		menuBar()->addAction(tr("Exit"), QApplication::instance(), SLOT(quit()));
+		menuBar()->addAction(tr("About"), this, SLOT(about()));
+		//menuBar()->addAction(tr("Change View"), this, SLOT(changeMode()));
+	}
+#endif
 }
 
 void eWallet::sort()
@@ -1125,6 +1180,12 @@ void eWallet::windowDestroyedEdit(QObject* obj)
 }
 
 void eWallet::viewTarget(Target * rent) {
+	if (!(detailWindow.isNull() && detailWindowEdit.isNull())) {
+		if (!detailWindow.isNull()) detailWindow->raise();
+		else
+		if (!detailWindowEdit.isNull()) detailWindowEdit->raise();
+		return ;
+	}
 
 	dbManager->getFields(rent);
 
@@ -1152,7 +1213,9 @@ void eWallet::import() {
 	                path,
 	                tr("Text files (*.txt);;"));
 
+#ifdef Q_WS_MAEMO_5
 	this->setAttribute(Qt::WA_Maemo5ShowProgressIndicator, true);
+#endif
 
 	if (!s.isNull () && !s.isEmpty ()) {
 		  QFile file(s);
@@ -1325,7 +1388,9 @@ void eWallet::import() {
 		    showInfo (true);
 		  }
 	}
+#ifdef Q_WS_MAEMO_5
 	this->setAttribute(Qt::WA_Maemo5ShowProgressIndicator, false);
+#endif
 }
 
 void eWallet::renameGroup () {
@@ -1430,7 +1495,9 @@ void eWallet::exportData() {
 	                path,
 	                tr("Text files (*.txt);;"));
 
+#ifdef Q_WS_MAEMO_5
 	this->setAttribute(Qt::WA_Maemo5ShowProgressIndicator, true);
+#endif
 	if (!s.isNull () && !s.isEmpty ()) {
 		if (!s.endsWith(".txt"))
 			s.append(".txt");
@@ -1521,10 +1588,19 @@ void eWallet::exportData() {
 		    file.close();
 		  }
 	}
+#ifdef Q_WS_MAEMO_5
 	this->setAttribute(Qt::WA_Maemo5ShowProgressIndicator, false);
+#endif
 }
 
 void eWallet::editTarget(Target * target) {
+	if (!(detailWindow.isNull() && detailWindowEdit.isNull())) {
+		if (!detailWindow.isNull()) detailWindow->raise();
+		else
+		if (!detailWindowEdit.isNull()) detailWindowEdit->raise();
+		return ;
+	}
+
 	dbManager->getFields(target);
 
 	if (detailWindowEdit.isNull()) {
@@ -1538,6 +1614,13 @@ void eWallet::editTarget(Target * target) {
 }
 
 void eWallet::duplicateTarget (Target * target) {
+	if (!(detailWindow.isNull() && detailWindowEdit.isNull())) {
+		if (!detailWindow.isNull()) detailWindow->raise();
+		else
+		if (!detailWindowEdit.isNull()) detailWindowEdit->raise();
+		return ;
+	}
+
 	dbManager->getFields(target);
 
 	if (detailWindowEdit.isNull()) {
@@ -1551,6 +1634,13 @@ void eWallet::duplicateTarget (Target * target) {
 }
 
 void eWallet::newLikeTarget (Target * target) {
+	if (!(detailWindow.isNull() && detailWindowEdit.isNull())) {
+		if (!detailWindow.isNull()) detailWindow->raise();
+		else
+		if (!detailWindowEdit.isNull()) detailWindowEdit->raise();
+		return ;
+	}
+
 	dbManager->getFields(target);
 
 	if (detailWindowEdit.isNull()) {
@@ -1564,6 +1654,13 @@ void eWallet::newLikeTarget (Target * target) {
 }
 
 void eWallet::newTarget() {
+	if (!(detailWindow.isNull() && detailWindowEdit.isNull())) {
+		if (!detailWindow.isNull()) detailWindow->raise();
+		else
+		if (!detailWindowEdit.isNull()) detailWindowEdit->raise();
+		return ;
+	}
+
 	if (detailWindowEdit.isNull()) {
 		detailWindowEdit = new DetailWindow(NULL, currentGroup != NULL ? *currentGroup : "", 0, true, this, this);
 		//detailWindowEdit->setAttribute(Qt::WA_Maemo5StackedWindow);
@@ -1626,8 +1723,18 @@ void eWallet::askPassword () {
 	isChangingPassword = false;
 	createMenu();
 
+	bool firstTime = !::dbManager->hasPassword ();
+#ifdef Q_WS_MAEMO_5
+	if (firstTime) {
+		show_banner (this, tr("Please, enter a password for your wallet"));
+	}
+	else {
+		show_banner (this, tr("Please, enter the password to unlock your wallet"));
+	}
+#endif
+
 	if (loginDialogDlg.isNull()) {
-		loginDialogDlg = new LoginDialog(!::dbManager->hasPassword (), this);
+		loginDialogDlg = new LoginDialog(firstTime, this);
 		setCentralWidget(loginDialogDlg);
 	}
 	loginDialogDlg->focus ();
@@ -1691,7 +1798,9 @@ void eWallet::reallyChangePassword (const QString & newPassword) {
 
 	//show_information_note (NULL, tr("Changing password, please wait until application quits"));
 
+#ifdef Q_WS_MAEMO_5
 	this->setAttribute(Qt::WA_Maemo5ShowProgressIndicator, true);
+#endif
 
 	MyThread t;
 	t.newPassword = newPassword;
@@ -1699,20 +1808,32 @@ void eWallet::reallyChangePassword (const QString & newPassword) {
 //	t.wait ();
 
 	while (t.isRunning()){
+#ifdef Q_WS_MAEMO_5
 		show_banner (this, tr("Changing password, please wait until application quits"));
+#endif
 		QApplication::instance()->processEvents();
 		t.wait (2000);
 	}
 
 	QString p = t.p; // ::dbManager->changePassword(newPassword);
 
-	//QMessageBox * messageBox = new QMessageBox (this);
+#ifndef Q_WS_MAEMO_5
+	QMessageBox * messageBox = new QMessageBox (this);
+#endif
 	if (p.length() == 0)
-		//messageBox->information(this, "Wallet", tr("Password changed successfully, application will exit"), QMessageBox::Ok);
+#ifndef Q_WS_MAEMO_5
+		messageBox->information(this, "Wallet", tr("Password changed successfully, application will exit"), QMessageBox::Ok);
+#endif
+#ifdef Q_WS_MAEMO_5
 		show_information_note (NULL, tr("Password changed successfully, application will exit"));
+#endif
 	else {
-		//messageBox->information(this, "Wallet", tr("Password CANNOT BE changed, because %1, and application will exit").arg(p) , QMessageBox::Ok);
+#ifndef Q_WS_MAEMO_5
+		messageBox->information(this, "Wallet", tr("Password CANNOT BE changed, because %1, and application will exit").arg(p) , QMessageBox::Ok);
+#endif
+#ifdef Q_WS_MAEMO_5
 		show_information_note (NULL, tr("Password CANNOT BE changed, because %1, and application will exit").arg(p));
+#endif
 	}
 
 	delete messageBox;
